import logging, string
from datetime import datetime
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django import newforms as forms
from google.appengine.api import users
from settings import STATIC_PATH
from shop.model import coffeeuser, coffeeshop
from shop.util import err_page

class ShopInfoForm(forms.Form):
    title = forms.CharField(label=_('Title'), widget=forms.TextInput(attrs={'size':'54','maxlength':'100'}))
    content = forms.CharField(label=_('Scene'), widget=forms.Textarea(attrs={'size':'2048','limit':'2048','cols':'52','rows':'10','wrap':'hard','class':'required'}))
    geo_point = forms.CharField(widget=forms.HiddenInput, required=False)
    
def new(req):
    user_info = users.get_current_user()
    if not user_info:
        return HttpResponseRedirect('/user/login/')
    
    if req.method == 'GET':
        s_form = ShopInfoForm(auto_id=True)
        context = {'static_path' : STATIC_PATH,
                   'user_info' : user_info,
                   'form' : s_form
                   }
        return render_to_response('shop_new.html', context)
    
    if req.method == 'POST':
        try:
            u_form = ShopInfoForm(req.POST)
            if not u_form.is_valid():
                return err_page('Invalid input values')
            
            u = coffeeuser.CoffeeUser.all().filter('user =', user_info).get()
            if not u:
                return err_page('Invalid user')
            
            latlng = None
            if req.POST.get('geo_point'):
                latlng = req.POST.get('geo_point').strip()
                latlng = string.replace(latlng, '(', '')
                latlng = string.replace(latlng, ')', '')
                
            c = coffeeshop.CoffeeShop(owner = u, nickname = u.nickname,
                                      title = unicode(req.POST['title'].strip(), 'utf8'),
                                      content = unicode(req.POST['content'].strip(), 'utf8'),
                                      geo_point = latlng,
                                      post_time = datetime.now()
                                      )
            c.put()
            return HttpResponseRedirect('/shop/'+str(c.key().id())+'/read/')
        except Exception, x:
            return err_page('Error.')
        
def read(req, shop_id):
    if req.method == 'GET':
        user_info = users.get_current_user()
        s = coffeeshop.CoffeeShop.get_by_id(int(shop_id))
        if not s:
            return err_page('Wromg request')
        context = {'static_path' : STATIC_PATH,
                   'user_info' : user_info,
                   'shop' : s
                   }
        return render_to_response('shop_read.html', context)
    
def modify(req, shop_id):
    user_info = users.get_current_user()
    if not user_info:
        return HttpResponseRedirect('/user/login/')
    
    if req.method == 'GET':
        c = coffeeshop.CoffeeShop.get_by_id(int(shop_id))
        if not c:
            return err_page('Wrong request')
        
        if c.owner.user != user_info:
            return err_page('You can not modify this infomation')
        
        if c.geo_point == None:
            c.geo_point = '37.5642, 126.9756'
        
        form_data = {'title' : c.title,
                     'content' : c.content,
                     'geo_point' : c.geo_point
                     }
        c_form = ShopInfoForm(form_data, auto_id=True)
        context = {'static_path' : STATIC_PATH,
                   'user_info' : user_info,
                   'form' : c_form
                   }
        return render_to_response('shop_modify.html', context)
    
    if req.method == 'POST':
        try:
            c_form = ShopInfoForm(req.POST)
            if not c_form.is_valid():
                return err_page('Invalid input values')
            
            u = coffeeuser.CoffeeUser.all().filter('user =', user_info).get()
            if not u:
                return err_page('Invalid user')
            
            c = coffeeshop.CoffeeShop.get_by_id(int(shop_id))
            if not c:
                return err_page('Wrong request')
            
            if c.owner.user != user_info:
                return err_page('You can not modify this infomation')

            latlng = None
            if req.POST.get('geo_point'):
                latlng = req.POST.get('geo_point').strip()
                latlng = string.replace(latlng, '(', '')
                latlng = string.replace(latlng, ')', '')
                
            c.nickname = u.nickname
            c.title = unicode(req.POST['title'].strip(), 'utf-8')
            c.content = unicode(req.POST['content'].strip(), 'utf-8')
            c.geo_point = latlng
            c.post_time = datetime.now()
            c.put()
            
            return HttpResponseRedirect('/shop/'+str(c.key().id())+'/read/')
        except Exception, x:
            return err_page('Error.')

def delete(req, shop_id):
    user_info = users.get_current_user()
    if not user_info:
        return HttpResponseRedirect('/user/login/')
    
    if req.method == 'GET':
        try:
            c = coffeeshop.CoffeeShop.get_by_id(int(shop_id))
            if not c:
                return err_page('Wrong request')
            
            if c.owner.user != user_info:
                return err_page('You can not modify this infomation')
            
            c.delete()
            return HttpResponseRedirect('/')
        except Exception, x:
            return err_page('Error')